#
# spec file for package swig (Version 1.3.36)
#
# Copyright (c) 2008 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           swig
BuildRequires:  boost-devel gcc-c++ python-devel
Url:            http://www.swig.org
License:        BSD 3-Clause
Group:          Development/Languages/C and C++
AutoReqProv:    on
Summary:        Simplified Wrapper and Interface Generator
Version:        1.3.36
Release:        2.4
Source:         swig-%{version}.tar.bz2
Patch1:         swig-1.3.36-perl-long-long.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SWIG is a compiler that attempts to make it easy to integrate C, C++,
or Objective-C code with scripting languages including Perl, Tcl, and
Python.  In a nutshell, you give it a bunch of ANSI C/C++ declarations
and it generates an interface between C and your favorite scripting
language.  However, this is only scratching the surface of what SWIG
can do--some of its more advanced features include automatic
documentation generation, module and library management, extensive
customization options, and more.



Authors:
--------
    Dave Beazley <beazley@cs.utah.edu>
    William S Fulton <wsf@fultondesigns.co.uk>

%package doc
License:        BSD 3-Clause
Summary:        SWIG Manual
Group:          Development/Languages/C and C++
Requires:       swig

%description doc
SWIG is a compiler that attempts to make it easy to integrate C, C++,
or Objective-C code with scripting languages including Perl, Tcl, and
Python.  In a nutshell, you give it a bunch of ANSI C/C++ declarations
and it generates an interface between C and your favorite scripting
language.  However, this is only scratching the surface of what SWIG
can do--some of its more advanced features include automatic
documentation generation, module and library management, extensive
customization options, and more.

This package contains the SWIG manual.



Authors:
--------
    Dave Beazley <beazley@cs.utah.edu>

%package examples
License:        BSD 3-Clause
Summary:        SWIG example files
Group:          Development/Languages/C and C++
Requires:       swig

%description examples
SWIG is a compiler that attempts to make it easy to integrate C, C++,
or Objective-C code with scripting languages including Perl, Tcl, and
Python.  In a nutshell, you give it a bunch of ANSI C/C++ declarations
and it generates an interface between C and your favorite scripting
language.  However, this is only scratching the surface of what SWIG
can do--some of its more advanced features include automatic
documentation generation, module and library management, extensive
customization options, and more.

This package contains SWIG examples, useful both for testing and
understandig SWIG usage.



Authors:
--------
    Dave Beazley <beazley@cs.utah.edu>

%prep
%setup -q
%patch1

%build
v1=$(awk '/^# Generated by GNU Autoconf / { print $6; exit; }' configure)
v2=$(autoconf -V | awk '/autoconf \(GNU Autoconf\)/ {print $4; exit}')
old=$(perl -e "print ($v1 <= $v2);")
if test "x$old" = "x1"; then
	./autogen.sh
fi
export CCSHARED="-fPIC -fno-strict-aliasing $RPM_OPT_FLAGS"
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"
./configure \
	--prefix=/usr \
	--libdir=%{_libdir}
make %{?jobs:-j%jobs}
make check

%install
make install DESTDIR=$RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT%{_docdir}/%{name}
cp -a FUTURE TODO NEW ANNOUNCE CHANGES* LICENSE README Doc/{Devel,Manual} \
	$RPM_BUILD_ROOT%{_docdir}/%{name}/
install -d $RPM_BUILD_ROOT%{_libdir}/swig
cp -a Examples $RPM_BUILD_ROOT%_libdir/swig/examples
# rm files that are not needed for runnig or rebuilding the examples
find $RPM_BUILD_ROOT%_libdir/swig \
	-name '*.dsp' -o -name '*.vcproj' -o -name '*.sln' -o \
	-name '*.o' -o -name '*_wrap.c' | xargs rm
# fix perms
chmod -x $RPM_BUILD_ROOT%_docdir/%name/Manual/*
find $RPM_BUILD_ROOT%_libdir/swig -name '*.h' -perm +111 | \
	xargs --no-run-if-empty chmod -x
ln -s %_libdir/swig/examples $RPM_BUILD_ROOT%_docdir/%name/Examples

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/[A-Z][A-Z]*
%{_datadir}/swig
%attr(755,root,root) %{_bindir}/swig

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}/Devel
%{_docdir}/%{name}/Manual

%files examples
%defattr(-,root,root)
%{_docdir}/%{name}/Examples
%{_libdir}/swig

%changelog
* Tue Oct 21 2008 mmarek@suse.cz
- fixed two integer overflows in perlprimtypes.swg. These were
  actually why the two tests on ppc failed. *sigh* (bnc#431945)
* Fri Sep 26 2008 mmarek@suse.cz
- disable two perl tests on ppc
* Wed Sep 24 2008 mmarek@suse.cz
- updated to 1.3.36
  * Enhancement to directors to wrap all protected members
  * Optimisation feature for objects returned by value
  * A few bugs fixes in the PHP, Java, Ruby, R, C#, Python, Lua and
    Perl modules
  * Other minor generic bug fixes
* Tue Apr  8 2008 mmarek@suse.cz
- updated to 1.3.35
  * Octave language module added
  * Bug fixes in Python, Lua, Java, C#, Perl modules
  * A few other generic bugs and runtime assertions fixed
* Wed Mar 26 2008 mmarek@suse.cz
- remove the croak patch, croak(Nullch) is correct (see
  https://sourceforge.net/tracker/?func=detail&atid=301645&aid=1925121&group_id=1645)
- testsuite-warnings.patch not needed
* Thu Mar 20 2008 pth@suse.de
- define SWIG_croak_null as croak("%%s","") not croak(Nullch)
  as croak is defined to take a string constant as 1st arg.
- Don't return an unitialized local variable in template code.
- Bracket if clauses so that the compiler doesn't warn in template code.
* Fri Feb 29 2008 mmarek@suse.cz
- updated to 1.3.34
  + shared_ptr support for Python
  + Support for latest R - version 2.6
  + Various minor improvements/bug fixes for R, Lua, Python, Java,
    C#
  + A few other generic bug fixes, mainly for templates and using
    statements
* Wed Nov 28 2007 mmarek@suse.cz
- updated to 1.3.33
  + shared_ptr support for Java and C#
  + Enhanced STL support for Ruby
  + Fixed long-standing memory leak in PHP Module
  + Numerous fixes and minor enhancements for Allegrocl, C#, cffi,
    Chicken, Guile, Java, Lua, Ocaml, Perl, PHP, Python, Ruby, Tcl
  + Improved warning support
* Wed Sep 19 2007 mmarek@suse.cz
- don't "update" autofoo when building for  older dists in the
  buildservice
* Tue May 29 2007 mmarek@suse.cz
- install examples in '%%%%_libdir/swig/examples' (not Examples) to
  pass the devel-file-in-non-devel-package rpmlint check
* Thu May 24 2007 mmarek@suse.cz
- fixed some rpmlint errors
* Wed Apr  4 2007 mmarek@suse.cz
- install the precompiled examples to %%%%_libdir/swig
* Wed Jan 24 2007 mmarek@suse.cz
- temporarily disabled li_std_string run test under perl5 on ix86
  and s390
- build examples and testsuite with -fno-strict-aliasing (packages
  using swig & python should do the same for now)
- fixed testsuite-warnings.patch
* Fri Dec 15 2006 mmarek@suse.cz
- updated to 1.3.31, for changes see
  http://swig.svn.sourceforge.net/viewvc/swig/trunk/CHANGES?r1=9073&r2=9585&diff_format=u
* Wed Nov  8 2006 mmarek@suse.cz
- fixed bug in the python module that caused aborts on some
  architectures
* Tue Nov  7 2006 mmarek@suse.cz
- don't install executable documentation files
* Fri Sep  8 2006 mmarek@suse.cz
- fixed for Python 2.5 (further fixes may be needed, at least it
  builds again)
  (python25.patch)
- use $RPM_OPT_FLAGS, unhide compilation of test wrappers (ditto)
  (testsuite.patch)
* Wed Sep  6 2006 mmarek@suse.de
- fixed build
* Wed Jul 26 2006 mmarek@suse.cz
- update to version 1.3.29
  * support for Common Lisp with CFFI
  * new %%extend_smart_pointer() directive to extend SWIG smart
    pointer support in Python
  * new %%bang directive for methods ending with exclamation marks
    in Ruby
  * New -autorename option for Ruby to rename methods to match
    Ruby naming conventions
  * enhancements to the %%rename directive
  * initial support for wrappint Java code in scripting languages
    using gcj
  * new %%copyctor directive for automatic generation of copy
    constructors
  * many more enhancements + bugfixes
- fixed top-level Makefile.in to work with autoconf-2.60
  (autoconf260.patch)
- added python-devel to buildrequires to test the Python module
  during build
* Thu Jul 20 2006 schwab@suse.de
- Fix missing slash.
* Mon Feb 27 2006 mmarek@suse.cz
- split documentation into swig-doc and swig-examples
  [#153015]
* Mon Jan 30 2006 mmarek@suse.cz
- fix build with perl-5.8.8 (thanks to Olaf Hering)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 mmarek@suse.cz
- use -fPIC instead of -fpic (-fpic didn't pass testsuite on s390x)
* Tue Jan 10 2006 mmarek@suse.cz
- fix endless loop when write fails
  [#141754] (write-loop.patch)
* Wed Nov 16 2005 ro@suse.de
- fix build on x86_64 (fPIC in gifplot)
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Wed Nov  2 2005 uli@suse.de
- update -> 1.3.27
- parallelize build
- run test suite
* Mon Apr 11 2005 mcihar@suse.cz
- update to 1.3.24 again, I hope that subversion guys will fix their
  problems till next release
* Mon Jan 24 2005 ro@suse.de
- fix swigpy build on lib64
* Thu Jan  6 2005 mcihar@suse.cz
- back to 1.3.21 due to subversion incompatibility
* Tue Dec 21 2004 mcihar@suse.cz
- update to 1.3.24
- our python now has sys.lib, so no need for patching
- spec file cleanup
- swiglibdir is now same as upstream - $datadir/swig/version
* Tue Nov 23 2004 mcihar@suse.cz
- update to 1.3.23
- runtime no more included
- remove most of buildrequires, as they're needed just for examples and
  they anyway don't compile out of the source directory
* Mon Apr 19 2004 mcihar@suse.cz
- -fno-strict-aliasing
* Mon Mar  8 2004 ro@suse.de
- added php4 to neededforbuild
- renamed mod_php4-devel to php4-devel in neededforbuild
* Fri Jan 23 2004 mcihar@suse.cz
- updated to 1.3.21
* Thu Dec 18 2003 mcihar@suse.cz
- Updated to 1.3.20. This release includes a large number of
  enhancements including improved C++ support, directors, contracts, and
  more.
* Fri Aug 15 2003 mcihar@suse.cz
- handle libdir correctly
* Thu Aug 14 2003 mcihar@suse.cz
- try to force swig compilation to accept CFLAGS
- cleaned up specfile
* Wed May 28 2003 mcihar@suse.cz
- add -fPIC
- fix libtool problems
* Tue May 27 2003 mcihar@suse.cz
- fixed permissions for files in lib
* Thu May 15 2003 mcihar@suse.cz
- fix permissions for documentation
* Mon May 12 2003 mcihar@suse.cz
- use swiglibdir to have save setup as previous versions
* Mon May 12 2003 mcihar@suse.cz
- updated to 1.3.19
- compile with -fPIC (should fix #26765)
* Thu Feb 13 2003 mcihar@suse.cz
- configure scripts finds correctly more requirements:
  - java includes
  - python on lib64
  - ocaml on lib64
- build more runtimes:
  - added php4
  - fixed perl
* Wed Jan 22 2003 mcihar@suse.cz
- not marking files as config, as they do not contain configuration
- simplified file list
* Mon Jan  6 2003 mcihar@suse.cz
- updated to 1.3.17:
  * added pike and ocaml bindings
  * many bugfixes
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Aug 14 2002 mls@suse.de
- made it work with threaded perl-5.8
* Thu Jun 27 2002 mcihar@suse.cz
- updated to 1.3.13
- added more documentation (html manual and some others)
* Tue Jun 11 2002 mls@suse.de
- delete bogus config.{log,status} from Examples/GIFPlot
* Tue May 21 2002 meissner@suse.de
- compile with tcl again (needs --with-tclconfig)
* Tue May 21 2002 ro@suse.de
- fix libdir usage
* Mon Jan 28 2002 tcrhak@suse.cz
- fixed parser.yxx to compile with bison 1.32
* Tue Jan  8 2002 cihlar@suse.cz
- fixed to compile with python 2.2
* Thu Dec  6 2001 cihlar@suse.cz
- update to version 1.3.9:
  * many fixes and improvements
- added libraries in /usr/lib
* Fri Jul 27 2001 cihlar@suse.cz
- update to version 1.3.6
- fixed call of suse_update_config
- call autoconf also in subdirs
- added xf86 to neededforbuild
* Sat Jan 20 2001 schwab@suse.de
- Fix last change to do it right.
* Fri Jan 19 2001 cihlar@suse.cz
- added swig1.3a5-Printv.dif.bz2 - fixed to work on ia64
* Wed Nov 29 2000 ro@suse.de
- changed neededforbuild <tcld> to <tcl-devel>
* Mon Nov 27 2000 cihlar@suse.cz
- removed kaffe from neededforbuild
* Fri Nov 17 2000 ro@suse.de
- fixed filelist
* Thu Nov 16 2000 cihlar@suse.cz
- fixed neededforbuild
* Thu Nov 16 2000 cihlar@suse.cz
- update to version 1.3a5
- fixed file list
- fixed neededforbuild
- improved optimalization
* Thu Aug 24 2000 cihlar@suse.cz
- update to version 1.3a3
- bzipped sources
* Wed Aug 16 2000 cihlar@suse.cz
- added BuildRoot
* Fri Jun  2 2000 kukuk@suse.de
- Use doc macro
* Mon Jan 31 2000 ro@suse.de
- fixed to compile
- man to /usr/share
* Sun Oct 17 1999 ro@suse.de
- fixed neededforbuild
* Fri Sep 17 1999 kettner@suse.de
- Reinserted old # Commandline: line.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon May  3 1999 kettner@suse.de
- Spec file created from swig1.1p5.tar.gz by autospec
